# Simbak

Simbak is a simple backup solution that is aimed towards individuals who just want a quick and easy way to backup their files.

---
## Benefits of simbak

- Simbak uses tar and gzip in order to store the backups, so that recovering the data in backups does not depend on simbak itself.
- Simbak is also very light, portable, and very easy to use, meaning that there's no large application to install.
- It's free and open source, meaning anyone can contribute or change simbak to meet their own needs.

---
## How to use simbak

